@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2021  The Software Heritage developers
+# Copyright (C) 2020-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,9 +6,11 @@
 from distutils.util import strtobool
 import json
 from typing import Dict, Iterator, Union
+from urllib.parse import unquote, urlparse, urlunparse
 
 import requests
 
+from django.http import QueryDict
 from django.http.response import StreamingHttpResponse
 from rest_framework.decorators import renderer_classes
 from rest_framework.renderers import JSONRenderer
@@ -135,11 +137,41 @@ def api_graph_proxy(
             return Response(
                 "You do not have permission to perform this action.", status=403
             )
-    graph_query_url = get_config()["graph"]["server_url"]
+
+    graph_config = get_config()["graph"]
+    graph_query = unquote(graph_query)
+    graph_query_url = graph_config["server_url"]
     graph_query_url += graph_query
-    if request.GET:
-        graph_query_url += "?" + request.GET.urlencode(safe="/;:")
+
+    parsed_url = urlparse(graph_query_url)
+    query_dict = QueryDict(parsed_url.query, mutable=True)
+    query_dict.update(request.GET)
+
+    # clamp max_edges query parameter according to authentication
+    if request.user.is_staff:
+        max_edges = graph_config["max_edges"]["staff"]
+    elif request.user.is_authenticated:
+        max_edges = graph_config["max_edges"]["user"]
+    else:
+        max_edges = graph_config["max_edges"]["anonymous"]
+    query_dict["max_edges"] = min(
+        max_edges, int(query_dict.get("max_edges", max_edges + 1))
+    )
+
+    if query_dict:
+        graph_query_url = urlunparse(
+            parsed_url._replace(query=query_dict.urlencode(safe="/;:"))
+        )
+
     response = requests.get(graph_query_url, stream=True)
+
+    if response.status_code != 200:
+        return Response(
+            response.content,
+            status=response.status_code,
+            content_type=response.headers["Content-Type"],
+        )
+
     # graph stats and counter endpoint responses are not streamed
     if response.headers.get("Transfer-Encoding") != "chunked":
         return Response(
