@@ -218,13 +218,15 @@ def prepare_content_for_display(content_data, mime_type, path):
         key 'language'.
     """
 
-    language = highlightjs.get_hljs_language_from_filename(path)
+    language = None
+    if path:
+        language = highlightjs.get_hljs_language_from_filename(path.split("/")[-1])
 
-    if not language:
+    if language is None:
         language = highlightjs.get_hljs_language_from_mime_type(mime_type)
 
-    if not language:
-        language = "nohighlight"
+    if language is None:
+        language = "plaintext"
 
     if mime_type.startswith("image/"):
         if mime_type in browsers_supported_image_mimes:
