@@ -26,7 +26,7 @@ from swh.web.tests.data import (
     ORIGIN_METADATA_KEY,
     ORIGIN_METADATA_VALUE,
 )
-from swh.web.tests.strategies import new_origin, new_snapshots, origin, visit_dates
+from swh.web.tests.strategies import new_origin, new_snapshots, visit_dates
 from swh.web.tests.utils import check_api_get_responses
 
 
@@ -322,7 +322,6 @@ def test_api_lookup_origin_visit_latest_with_snapshot(
         assert rv.data == expected_visit
 
 
-@given(origin())
 def test_api_lookup_origin_visit_not_found(api_client, origin):
 
     all_visits = list(reversed(get_origin_visits(origin)))
@@ -394,7 +393,6 @@ def test_api_origins_scroll(api_client, archive_data, origin_count):
     assert {origin["url"] for origin in results} == origin_urls
 
 
-@given(origin())
 def test_api_origin_by_url(api_client, archive_data, origin):
     origin_url = origin["url"]
     url = reverse("api-1-origin", url_args={"origin_url": origin_url})
@@ -547,11 +545,6 @@ def test_api_origin_search_visit_type(api_client, mocker, backend):
 
 
 def test_api_origin_search_use_ql(api_client, mocker):
-    mock_config = mocker.patch("swh.web.common.archive.config")
-    mock_config.get_config.return_value = {
-        "search_config": {"metadata_backend": "swh-search", "enable_ql": True}
-    }
-
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
         "https://github.com/memononen/libtess2",
@@ -564,14 +557,20 @@ def test_api_origin_search_use_ql(api_client, mocker):
         results=ORIGINS, next_page_token=None,
     )
 
+    query = "origin = 'github.com'"
+
     url = reverse(
         "api-1-origin-search",
-        url_args={"url_pattern": "origin = 'github.com'",},
+        url_args={"url_pattern": query},
         query_params={"visit_type": "git", "use_ql": "true"},
     )
     rv = check_api_get_responses(api_client, url, status_code=200)
     assert {origin["url"] for origin in rv.data} == expected_origins
 
+    mock_archive_search.origin_search.assert_called_with(
+        query=query, page_token=None, with_visit=False, visit_types=["git"], limit=70
+    )
+
 
 @pytest.mark.parametrize("backend", ["swh-search", "swh-storage"])
 @pytest.mark.parametrize("limit", [1, 2, 3, 10])
@@ -705,7 +704,6 @@ def test_api_origin_metadata_search_limit(api_client, mocker):
     oimsft.assert_called_with(conjunction=[ORIGIN_METADATA_VALUE], limit=100)
 
 
-@given(origin())
 def test_api_origin_intrinsic_metadata(api_client, origin):
 
     url = reverse(
