@@ -84,8 +84,10 @@ def test_content_view_no_highlight(
 
         content_display = _process_content_for_display(archive_data, content)
 
-        assert_contains(resp, '<code class="nohighlight">')
-        assert_contains(resp, escape(content_display["content_data"]))
+        if content["encoding"] != "binary":
+            assert_contains(resp, '<code class="plaintext">')
+            assert_contains(resp, escape(content_display["content_data"]))
+
         assert_contains(resp, url_raw)
 
         swh_cnt_id = gen_swhid(ObjectType.CONTENT, sha1_git)
